package com.ruoyi.postCheck.service.impl;

import java.util.List;

import com.baomidou.mybatisplus.core.toolkit.IdWorker;
import com.ruoyi.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.postCheck.mapper.PostCheckedProblemRecordMapper;
import com.ruoyi.postCheck.domain.PostCheckedProblemRecord;
import com.ruoyi.postCheck.service.IPostCheckedProblemRecordService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;

/**
 * 岗检问题操作记录表Service业务层处理
 *
 * @author csg
 * @date 2023-12-23
 */
@Service
public class PostCheckedProblemRecordServiceImpl extends ServiceImpl<PostCheckedProblemRecordMapper, PostCheckedProblemRecord> implements IPostCheckedProblemRecordService {
    @Autowired
    private PostCheckedProblemRecordMapper postCheckedProblemRecordMapper;

    /**
     * 查询岗检问题操作记录表
     *
     * @param id 岗检问题操作记录表主键
     * @return 岗检问题操作记录表
    @Override
    public PostCheckedProblemRecord selectPostCheckedProblemRecordById(Long id) {
        return postCheckedProblemRecordMapper.selectPostCheckedProblemRecordById(id);
    }
     */

    /**
     * 查询岗检问题操作记录表列表
     *
     * @param postCheckedProblemRecord 岗检问题操作记录表
     * @return 岗检问题操作记录表
     */
    @Override
    public List<PostCheckedProblemRecord> selectPostCheckedProblemRecordList(PostCheckedProblemRecord postCheckedProblemRecord) {
        return postCheckedProblemRecordMapper.selectPostCheckedProblemRecordList(postCheckedProblemRecord);
    }

    /**
     * 新增岗检问题操作记录表
     *
     * @param postCheckedProblemRecord 岗检问题操作记录表
     * @return 结果
     */
    @Override
    public int insertPostCheckedProblemRecord(PostCheckedProblemRecord postCheckedProblemRecord) {
        //TODO 自增主键修改为-MyBatis-Plus雪花算法(截取5位解决VUE精度丢失BUG)-系统登录日志
        if (postCheckedProblemRecord.getId() == null)
            postCheckedProblemRecord.setId(Long.parseLong(IdWorker.getIdStr().substring(4)));
        // postCheckedProblemRecord.setCreateTime(DateUtils.getNowDate());
//        postCheckedProblemRecord.setCreateDefault();
        return postCheckedProblemRecordMapper.insertPostCheckedProblemRecord(postCheckedProblemRecord);
    }

    /**
     * 修改岗检问题操作记录表
     *
     * @param postCheckedProblemRecord 岗检问题操作记录表
     * @return 结果
    @Override
    public int updatePostCheckedProblemRecord(PostCheckedProblemRecord postCheckedProblemRecord) {
        // postCheckedProblemRecord.setUpdateTime(DateUtils.getNowDate());
        postCheckedProblemRecord.setUpdateDefault();
        return postCheckedProblemRecordMapper.updatePostCheckedProblemRecord(postCheckedProblemRecord);
    }
     */

    /**
     * 批量删除岗检问题操作记录表
     *
     * @param ids 需要删除的岗检问题操作记录表主键
     * @return 结果
    @Override
    public int deletePostCheckedProblemRecordByIds(Long[] ids) {
        return postCheckedProblemRecordMapper.deletePostCheckedProblemRecordByIds(ids);
    }
     */

    /**
     * 删除岗检问题操作记录表信息
     *
     * @param id 岗检问题操作记录表主键
     * @return 结果
    @Override
    public int deletePostCheckedProblemRecordById(Long id) {
        return postCheckedProblemRecordMapper.deletePostCheckedProblemRecordById(id);
    }
     */
}
